@@ -2,6 +2,259 @@
 /* Generated data (by glib-mkenums) */
 
 #include "arvenumtypes.h"
+#include "arvbuffer.h"
+
+GType
+arv_buffer_status_get_type (void)
+{
+	static GType the_type = 0;
+
+	if (the_type == 0)
+	{
+		static const GEnumValue values[] = {
+			{ ARV_BUFFER_STATUS_UNKNOWN,
+			  "ARV_BUFFER_STATUS_UNKNOWN",
+			  "unknown" },
+			{ ARV_BUFFER_STATUS_SUCCESS,
+			  "ARV_BUFFER_STATUS_SUCCESS",
+			  "success" },
+			{ ARV_BUFFER_STATUS_CLEARED,
+			  "ARV_BUFFER_STATUS_CLEARED",
+			  "cleared" },
+			{ ARV_BUFFER_STATUS_TIMEOUT,
+			  "ARV_BUFFER_STATUS_TIMEOUT",
+			  "timeout" },
+			{ ARV_BUFFER_STATUS_MISSING_PACKETS,
+			  "ARV_BUFFER_STATUS_MISSING_PACKETS",
+			  "missing-packets" },
+			{ ARV_BUFFER_STATUS_WRONG_PACKET_ID,
+			  "ARV_BUFFER_STATUS_WRONG_PACKET_ID",
+			  "wrong-packet-id" },
+			{ ARV_BUFFER_STATUS_SIZE_MISMATCH,
+			  "ARV_BUFFER_STATUS_SIZE_MISMATCH",
+			  "size-mismatch" },
+			{ ARV_BUFFER_STATUS_FILLING,
+			  "ARV_BUFFER_STATUS_FILLING",
+			  "filling" },
+			{ ARV_BUFFER_STATUS_ABORTED,
+			  "ARV_BUFFER_STATUS_ABORTED",
+			  "aborted" },
+			{ 0, NULL, NULL }
+		};
+		the_type = g_enum_register_static (
+				g_intern_static_string ("ArvBufferStatus"),
+				values);
+	}
+	return the_type;
+}
+
+GType
+arv_buffer_payload_type_get_type (void)
+{
+	static GType the_type = 0;
+
+	if (the_type == 0)
+	{
+		static const GEnumValue values[] = {
+			{ ARV_BUFFER_PAYLOAD_TYPE_UNKNOWN,
+			  "ARV_BUFFER_PAYLOAD_TYPE_UNKNOWN",
+			  "unknown" },
+			{ ARV_BUFFER_PAYLOAD_TYPE_IMAGE,
+			  "ARV_BUFFER_PAYLOAD_TYPE_IMAGE",
+			  "image" },
+			{ ARV_BUFFER_PAYLOAD_TYPE_RAWDATA,
+			  "ARV_BUFFER_PAYLOAD_TYPE_RAWDATA",
+			  "rawdata" },
+			{ ARV_BUFFER_PAYLOAD_TYPE_FILE,
+			  "ARV_BUFFER_PAYLOAD_TYPE_FILE",
+			  "file" },
+			{ ARV_BUFFER_PAYLOAD_TYPE_CHUNK_DATA,
+			  "ARV_BUFFER_PAYLOAD_TYPE_CHUNK_DATA",
+			  "chunk-data" },
+			{ ARV_BUFFER_PAYLOAD_TYPE_EXTENDED_CHUNK_DATA,
+			  "ARV_BUFFER_PAYLOAD_TYPE_EXTENDED_CHUNK_DATA",
+			  "extended-chunk-data" },
+			{ ARV_BUFFER_PAYLOAD_TYPE_JPEG,
+			  "ARV_BUFFER_PAYLOAD_TYPE_JPEG",
+			  "jpeg" },
+			{ ARV_BUFFER_PAYLOAD_TYPE_JPEG2000,
+			  "ARV_BUFFER_PAYLOAD_TYPE_JPEG2000",
+			  "jpeg2000" },
+			{ ARV_BUFFER_PAYLOAD_TYPE_H264,
+			  "ARV_BUFFER_PAYLOAD_TYPE_H264",
+			  "h264" },
+			{ ARV_BUFFER_PAYLOAD_TYPE_MULTIZONE_IMAGE,
+			  "ARV_BUFFER_PAYLOAD_TYPE_MULTIZONE_IMAGE",
+			  "multizone-image" },
+			{ 0, NULL, NULL }
+		};
+		the_type = g_enum_register_static (
+				g_intern_static_string ("ArvBufferPayloadType"),
+				values);
+	}
+	return the_type;
+}
+
+#include "arvchunkparser.h"
+
+GType
+arv_chunk_parser_status_get_type (void)
+{
+	static GType the_type = 0;
+
+	if (the_type == 0)
+	{
+		static const GEnumValue values[] = {
+			{ ARV_CHUNK_PARSER_STATUS_UNKNOWN,
+			  "ARV_CHUNK_PARSER_STATUS_UNKNOWN",
+			  "unknown" },
+			{ ARV_CHUNK_PARSER_STATUS_SUCCESS,
+			  "ARV_CHUNK_PARSER_STATUS_SUCCESS",
+			  "success" },
+			{ ARV_CHUNK_PARSER_STATUS_BUFFER_NOT_FOUND,
+			  "ARV_CHUNK_PARSER_STATUS_BUFFER_NOT_FOUND",
+			  "buffer-not-found" },
+			{ ARV_CHUNK_PARSER_STATUS_CHUNK_NOT_FOUND,
+			  "ARV_CHUNK_PARSER_STATUS_CHUNK_NOT_FOUND",
+			  "chunk-not-found" },
+			{ ARV_CHUNK_PARSER_STATUS_INVALID_FEATURE_NAME,
+			  "ARV_CHUNK_PARSER_STATUS_INVALID_FEATURE_NAME",
+			  "invalid-feature-name" },
+			{ 0, NULL, NULL }
+		};
+		the_type = g_enum_register_static (
+				g_intern_static_string ("ArvChunkParserStatus"),
+				values);
+	}
+	return the_type;
+}
+
+#include "arvdebug.h"
+
+GType
+arv_debug_level_get_type (void)
+{
+	static GType the_type = 0;
+
+	if (the_type == 0)
+	{
+		static const GEnumValue values[] = {
+			{ ARV_DEBUG_LEVEL_NONE,
+			  "ARV_DEBUG_LEVEL_NONE",
+			  "none" },
+			{ ARV_DEBUG_LEVEL_WARNING,
+			  "ARV_DEBUG_LEVEL_WARNING",
+			  "warning" },
+			{ ARV_DEBUG_LEVEL_DEBUG,
+			  "ARV_DEBUG_LEVEL_DEBUG",
+			  "debug" },
+			{ ARV_DEBUG_LEVEL_LOG,
+			  "ARV_DEBUG_LEVEL_LOG",
+			  "log" },
+			{ ARV_DEBUG_LEVEL_COUNT,
+			  "ARV_DEBUG_LEVEL_COUNT",
+			  "count" },
+			{ 0, NULL, NULL }
+		};
+		the_type = g_enum_register_static (
+				g_intern_static_string ("ArvDebugLevel"),
+				values);
+	}
+	return the_type;
+}
+
+#include "arvdevice.h"
+
+GType
+arv_device_status_get_type (void)
+{
+	static GType the_type = 0;
+
+	if (the_type == 0)
+	{
+		static const GEnumValue values[] = {
+			{ ARV_DEVICE_STATUS_UNKNOWN,
+			  "ARV_DEVICE_STATUS_UNKNOWN",
+			  "unknown" },
+			{ ARV_DEVICE_STATUS_SUCCESS,
+			  "ARV_DEVICE_STATUS_SUCCESS",
+			  "success" },
+			{ ARV_DEVICE_STATUS_TIMEOUT,
+			  "ARV_DEVICE_STATUS_TIMEOUT",
+			  "timeout" },
+			{ ARV_DEVICE_STATUS_WRITE_ERROR,
+			  "ARV_DEVICE_STATUS_WRITE_ERROR",
+			  "write-error" },
+			{ ARV_DEVICE_STATUS_TRANSFER_ERROR,
+			  "ARV_DEVICE_STATUS_TRANSFER_ERROR",
+			  "transfer-error" },
+			{ ARV_DEVICE_STATUS_NOT_CONNECTED,
+			  "ARV_DEVICE_STATUS_NOT_CONNECTED",
+			  "not-connected" },
+			{ 0, NULL, NULL }
+		};
+		the_type = g_enum_register_static (
+				g_intern_static_string ("ArvDeviceStatus"),
+				values);
+	}
+	return the_type;
+}
+
+#include "arvdomnode.h"
+
+GType
+arv_dom_node_type_get_type (void)
+{
+	static GType the_type = 0;
+
+	if (the_type == 0)
+	{
+		static const GEnumValue values[] = {
+			{ ARV_DOM_NODE_TYPE_ELEMENT_NODE,
+			  "ARV_DOM_NODE_TYPE_ELEMENT_NODE",
+			  "element-node" },
+			{ ARV_DOM_NODE_TYPE_ATTRIBUTE_NODE,
+			  "ARV_DOM_NODE_TYPE_ATTRIBUTE_NODE",
+			  "attribute-node" },
+			{ ARV_DOM_NODE_TYPE_TEXT_NODE,
+			  "ARV_DOM_NODE_TYPE_TEXT_NODE",
+			  "text-node" },
+			{ ARV_DOM_NODE_TYPE_CDATA_SECTION_NODE,
+			  "ARV_DOM_NODE_TYPE_CDATA_SECTION_NODE",
+			  "cdata-section-node" },
+			{ ARV_DOM_NODE_TYPE_ENTITY_REFERENCE_NODE,
+			  "ARV_DOM_NODE_TYPE_ENTITY_REFERENCE_NODE",
+			  "entity-reference-node" },
+			{ ARV_DOM_NODE_TYPE_ENTITY_NODE,
+			  "ARV_DOM_NODE_TYPE_ENTITY_NODE",
+			  "entity-node" },
+			{ ARV_DOM_NODE_TYPE_PROCESSING_INSTRUCTION_NODE,
+			  "ARV_DOM_NODE_TYPE_PROCESSING_INSTRUCTION_NODE",
+			  "processing-instruction-node" },
+			{ ARV_DOM_NODE_TYPE_COMMENT_NODE,
+			  "ARV_DOM_NODE_TYPE_COMMENT_NODE",
+			  "comment-node" },
+			{ ARV_DOM_NODE_TYPE_DOCUMENT_NODE,
+			  "ARV_DOM_NODE_TYPE_DOCUMENT_NODE",
+			  "document-node" },
+			{ ARV_DOM_NODE_TYPE_DOCUMENT_TYPE_NODE,
+			  "ARV_DOM_NODE_TYPE_DOCUMENT_TYPE_NODE",
+			  "document-type-node" },
+			{ ARV_DOM_NODE_TYPE_DOCUMENT_FRAGMENT_NODE,
+			  "ARV_DOM_NODE_TYPE_DOCUMENT_FRAGMENT_NODE",
+			  "document-fragment-node" },
+			{ ARV_DOM_NODE_TYPE_NOTATION_NODE,
+			  "ARV_DOM_NODE_TYPE_NOTATION_NODE",
+			  "notation-node" },
+			{ 0, NULL, NULL }
+		};
+		the_type = g_enum_register_static (
+				g_intern_static_string ("ArvDomNodeType"),
+				values);
+	}
+	return the_type;
+}
+
 #include "arvenums.h"
 
 GType
@@ -131,95 +384,6 @@ arv_acquisition_mode_get_type (void)
 	return the_type;
 }
 
-#include "arvdebug.h"
-
-GType
-arv_debug_level_get_type (void)
-{
-	static GType the_type = 0;
-
-	if (the_type == 0)
-	{
-		static const GEnumValue values[] = {
-			{ ARV_DEBUG_LEVEL_NONE,
-			  "ARV_DEBUG_LEVEL_NONE",
-			  "none" },
-			{ ARV_DEBUG_LEVEL_WARNING,
-			  "ARV_DEBUG_LEVEL_WARNING",
-			  "warning" },
-			{ ARV_DEBUG_LEVEL_DEBUG,
-			  "ARV_DEBUG_LEVEL_DEBUG",
-			  "debug" },
-			{ ARV_DEBUG_LEVEL_LOG,
-			  "ARV_DEBUG_LEVEL_LOG",
-			  "log" },
-			{ ARV_DEBUG_LEVEL_COUNT,
-			  "ARV_DEBUG_LEVEL_COUNT",
-			  "count" },
-			{ 0, NULL, NULL }
-		};
-		the_type = g_enum_register_static (
-				g_intern_static_string ("ArvDebugLevel"),
-				values);
-	}
-	return the_type;
-}
-
-#include "arvdomnode.h"
-
-GType
-arv_dom_node_type_get_type (void)
-{
-	static GType the_type = 0;
-
-	if (the_type == 0)
-	{
-		static const GEnumValue values[] = {
-			{ ARV_DOM_NODE_TYPE_ELEMENT_NODE,
-			  "ARV_DOM_NODE_TYPE_ELEMENT_NODE",
-			  "element-node" },
-			{ ARV_DOM_NODE_TYPE_ATTRIBUTE_NODE,
-			  "ARV_DOM_NODE_TYPE_ATTRIBUTE_NODE",
-			  "attribute-node" },
-			{ ARV_DOM_NODE_TYPE_TEXT_NODE,
-			  "ARV_DOM_NODE_TYPE_TEXT_NODE",
-			  "text-node" },
-			{ ARV_DOM_NODE_TYPE_CDATA_SECTION_NODE,
-			  "ARV_DOM_NODE_TYPE_CDATA_SECTION_NODE",
-			  "cdata-section-node" },
-			{ ARV_DOM_NODE_TYPE_ENTITY_REFERENCE_NODE,
-			  "ARV_DOM_NODE_TYPE_ENTITY_REFERENCE_NODE",
-			  "entity-reference-node" },
-			{ ARV_DOM_NODE_TYPE_ENTITY_NODE,
-			  "ARV_DOM_NODE_TYPE_ENTITY_NODE",
-			  "entity-node" },
-			{ ARV_DOM_NODE_TYPE_PROCESSING_INSTRUCTION_NODE,
-			  "ARV_DOM_NODE_TYPE_PROCESSING_INSTRUCTION_NODE",
-			  "processing-instruction-node" },
-			{ ARV_DOM_NODE_TYPE_COMMENT_NODE,
-			  "ARV_DOM_NODE_TYPE_COMMENT_NODE",
-			  "comment-node" },
-			{ ARV_DOM_NODE_TYPE_DOCUMENT_NODE,
-			  "ARV_DOM_NODE_TYPE_DOCUMENT_NODE",
-			  "document-node" },
-			{ ARV_DOM_NODE_TYPE_DOCUMENT_TYPE_NODE,
-			  "ARV_DOM_NODE_TYPE_DOCUMENT_TYPE_NODE",
-			  "document-type-node" },
-			{ ARV_DOM_NODE_TYPE_DOCUMENT_FRAGMENT_NODE,
-			  "ARV_DOM_NODE_TYPE_DOCUMENT_FRAGMENT_NODE",
-			  "document-fragment-node" },
-			{ ARV_DOM_NODE_TYPE_NOTATION_NODE,
-			  "ARV_DOM_NODE_TYPE_NOTATION_NODE",
-			  "notation-node" },
-			{ 0, NULL, NULL }
-		};
-		the_type = g_enum_register_static (
-				g_intern_static_string ("ArvDomNodeType"),
-				values);
-	}
-	return the_type;
-}
-
 #include "arvgc.h"
 
 GType
@@ -348,6 +512,12 @@ arv_gc_property_node_type_get_type (void)
 			{ ARV_GC_PROPERTY_NODE_TYPE_CHUNK_ID,
 			  "ARV_GC_PROPERTY_NODE_TYPE_CHUNK_ID",
 			  "chunk-id" },
+			{ ARV_GC_PROPERTY_NODE_TYPE_VALUE_INDEXED,
+			  "ARV_GC_PROPERTY_NODE_TYPE_VALUE_INDEXED",
+			  "value-indexed" },
+			{ ARV_GC_PROPERTY_NODE_TYPE_VALUE_DEFAULT,
+			  "ARV_GC_PROPERTY_NODE_TYPE_VALUE_DEFAULT",
+			  "value-default" },
 			{ ARV_GC_PROPERTY_NODE_TYPE_P_UNKNONW,
 			  "ARV_GC_PROPERTY_NODE_TYPE_P_UNKNONW",
 			  "p-unknonw" },
@@ -396,6 +566,12 @@ arv_gc_property_node_type_get_type (void)
 			{ ARV_GC_PROPERTY_NODE_TYPE_P_COMMAND_VALUE,
 			  "ARV_GC_PROPERTY_NODE_TYPE_P_COMMAND_VALUE",
 			  "p-command-value" },
+			{ ARV_GC_PROPERTY_NODE_TYPE_P_VALUE_INDEXED,
+			  "ARV_GC_PROPERTY_NODE_TYPE_P_VALUE_INDEXED",
+			  "p-value-indexed" },
+			{ ARV_GC_PROPERTY_NODE_TYPE_P_VALUE_DEFAULT,
+			  "ARV_GC_PROPERTY_NODE_TYPE_P_VALUE_DEFAULT",
+			  "p-value-default" },
 			{ 0, NULL, NULL }
 		};
 		the_type = g_enum_register_static (
@@ -465,294 +641,6 @@ arv_gc_register_node_type_get_type (void)
 	return the_type;
 }
 
-#include "arvdevice.h"
-
-GType
-arv_device_status_get_type (void)
-{
-	static GType the_type = 0;
-
-	if (the_type == 0)
-	{
-		static const GEnumValue values[] = {
-			{ ARV_DEVICE_STATUS_UNKNOWN,
-			  "ARV_DEVICE_STATUS_UNKNOWN",
-			  "unknown" },
-			{ ARV_DEVICE_STATUS_SUCCESS,
-			  "ARV_DEVICE_STATUS_SUCCESS",
-			  "success" },
-			{ ARV_DEVICE_STATUS_TIMEOUT,
-			  "ARV_DEVICE_STATUS_TIMEOUT",
-			  "timeout" },
-			{ ARV_DEVICE_STATUS_WRITE_ERROR,
-			  "ARV_DEVICE_STATUS_WRITE_ERROR",
-			  "write-error" },
-			{ ARV_DEVICE_STATUS_TRANSFER_ERROR,
-			  "ARV_DEVICE_STATUS_TRANSFER_ERROR",
-			  "transfer-error" },
-			{ ARV_DEVICE_STATUS_NOT_CONNECTED,
-			  "ARV_DEVICE_STATUS_NOT_CONNECTED",
-			  "not-connected" },
-			{ 0, NULL, NULL }
-		};
-		the_type = g_enum_register_static (
-				g_intern_static_string ("ArvDeviceStatus"),
-				values);
-	}
-	return the_type;
-}
-
-#include "arvstream.h"
-
-GType
-arv_stream_callback_type_get_type (void)
-{
-	static GType the_type = 0;
-
-	if (the_type == 0)
-	{
-		static const GEnumValue values[] = {
-			{ ARV_STREAM_CALLBACK_TYPE_INIT,
-			  "ARV_STREAM_CALLBACK_TYPE_INIT",
-			  "init" },
-			{ ARV_STREAM_CALLBACK_TYPE_EXIT,
-			  "ARV_STREAM_CALLBACK_TYPE_EXIT",
-			  "exit" },
-			{ ARV_STREAM_CALLBACK_TYPE_START_BUFFER,
-			  "ARV_STREAM_CALLBACK_TYPE_START_BUFFER",
-			  "start-buffer" },
-			{ ARV_STREAM_CALLBACK_TYPE_BUFFER_DONE,
-			  "ARV_STREAM_CALLBACK_TYPE_BUFFER_DONE",
-			  "buffer-done" },
-			{ 0, NULL, NULL }
-		};
-		the_type = g_enum_register_static (
-				g_intern_static_string ("ArvStreamCallbackType"),
-				values);
-	}
-	return the_type;
-}
-
-#include "arvbuffer.h"
-
-GType
-arv_buffer_status_get_type (void)
-{
-	static GType the_type = 0;
-
-	if (the_type == 0)
-	{
-		static const GEnumValue values[] = {
-			{ ARV_BUFFER_STATUS_UNKNOWN,
-			  "ARV_BUFFER_STATUS_UNKNOWN",
-			  "unknown" },
-			{ ARV_BUFFER_STATUS_SUCCESS,
-			  "ARV_BUFFER_STATUS_SUCCESS",
-			  "success" },
-			{ ARV_BUFFER_STATUS_CLEARED,
-			  "ARV_BUFFER_STATUS_CLEARED",
-			  "cleared" },
-			{ ARV_BUFFER_STATUS_TIMEOUT,
-			  "ARV_BUFFER_STATUS_TIMEOUT",
-			  "timeout" },
-			{ ARV_BUFFER_STATUS_MISSING_PACKETS,
-			  "ARV_BUFFER_STATUS_MISSING_PACKETS",
-			  "missing-packets" },
-			{ ARV_BUFFER_STATUS_WRONG_PACKET_ID,
-			  "ARV_BUFFER_STATUS_WRONG_PACKET_ID",
-			  "wrong-packet-id" },
-			{ ARV_BUFFER_STATUS_SIZE_MISMATCH,
-			  "ARV_BUFFER_STATUS_SIZE_MISMATCH",
-			  "size-mismatch" },
-			{ ARV_BUFFER_STATUS_FILLING,
-			  "ARV_BUFFER_STATUS_FILLING",
-			  "filling" },
-			{ ARV_BUFFER_STATUS_ABORTED,
-			  "ARV_BUFFER_STATUS_ABORTED",
-			  "aborted" },
-			{ 0, NULL, NULL }
-		};
-		the_type = g_enum_register_static (
-				g_intern_static_string ("ArvBufferStatus"),
-				values);
-	}
-	return the_type;
-}
-
-GType
-arv_buffer_payload_type_get_type (void)
-{
-	static GType the_type = 0;
-
-	if (the_type == 0)
-	{
-		static const GEnumValue values[] = {
-			{ ARV_BUFFER_PAYLOAD_TYPE_UNKNOWN,
-			  "ARV_BUFFER_PAYLOAD_TYPE_UNKNOWN",
-			  "unknown" },
-			{ ARV_BUFFER_PAYLOAD_TYPE_IMAGE,
-			  "ARV_BUFFER_PAYLOAD_TYPE_IMAGE",
-			  "image" },
-			{ ARV_BUFFER_PAYLOAD_TYPE_RAWDATA,
-			  "ARV_BUFFER_PAYLOAD_TYPE_RAWDATA",
-			  "rawdata" },
-			{ ARV_BUFFER_PAYLOAD_TYPE_FILE,
-			  "ARV_BUFFER_PAYLOAD_TYPE_FILE",
-			  "file" },
-			{ ARV_BUFFER_PAYLOAD_TYPE_CHUNK_DATA,
-			  "ARV_BUFFER_PAYLOAD_TYPE_CHUNK_DATA",
-			  "chunk-data" },
-			{ ARV_BUFFER_PAYLOAD_TYPE_EXTENDED_CHUNK_DATA,
-			  "ARV_BUFFER_PAYLOAD_TYPE_EXTENDED_CHUNK_DATA",
-			  "extended-chunk-data" },
-			{ ARV_BUFFER_PAYLOAD_TYPE_JPEG,
-			  "ARV_BUFFER_PAYLOAD_TYPE_JPEG",
-			  "jpeg" },
-			{ ARV_BUFFER_PAYLOAD_TYPE_JPEG2000,
-			  "ARV_BUFFER_PAYLOAD_TYPE_JPEG2000",
-			  "jpeg2000" },
-			{ ARV_BUFFER_PAYLOAD_TYPE_H264,
-			  "ARV_BUFFER_PAYLOAD_TYPE_H264",
-			  "h264" },
-			{ ARV_BUFFER_PAYLOAD_TYPE_MULTIZONE_IMAGE,
-			  "ARV_BUFFER_PAYLOAD_TYPE_MULTIZONE_IMAGE",
-			  "multizone-image" },
-			{ 0, NULL, NULL }
-		};
-		the_type = g_enum_register_static (
-				g_intern_static_string ("ArvBufferPayloadType"),
-				values);
-	}
-	return the_type;
-}
-
-#include "arvchunkparser.h"
-
-GType
-arv_chunk_parser_status_get_type (void)
-{
-	static GType the_type = 0;
-
-	if (the_type == 0)
-	{
-		static const GEnumValue values[] = {
-			{ ARV_CHUNK_PARSER_STATUS_UNKNOWN,
-			  "ARV_CHUNK_PARSER_STATUS_UNKNOWN",
-			  "unknown" },
-			{ ARV_CHUNK_PARSER_STATUS_SUCCESS,
-			  "ARV_CHUNK_PARSER_STATUS_SUCCESS",
-			  "success" },
-			{ ARV_CHUNK_PARSER_STATUS_BUFFER_NOT_FOUND,
-			  "ARV_CHUNK_PARSER_STATUS_BUFFER_NOT_FOUND",
-			  "buffer-not-found" },
-			{ ARV_CHUNK_PARSER_STATUS_CHUNK_NOT_FOUND,
-			  "ARV_CHUNK_PARSER_STATUS_CHUNK_NOT_FOUND",
-			  "chunk-not-found" },
-			{ ARV_CHUNK_PARSER_STATUS_INVALID_FEATURE_NAME,
-			  "ARV_CHUNK_PARSER_STATUS_INVALID_FEATURE_NAME",
-			  "invalid-feature-name" },
-			{ 0, NULL, NULL }
-		};
-		the_type = g_enum_register_static (
-				g_intern_static_string ("ArvChunkParserStatus"),
-				values);
-	}
-	return the_type;
-}
-
-#include "arvgvstream.h"
-
-GType
-arv_gv_stream_option_get_type (void)
-{
-	static GType the_type = 0;
-
-	if (the_type == 0)
-	{
-		static const GEnumValue values[] = {
-			{ ARV_GV_STREAM_OPTION_NONE,
-			  "ARV_GV_STREAM_OPTION_NONE",
-			  "none" },
-			{ ARV_GV_STREAM_OPTION_PACKET_SOCKET_DISABLED,
-			  "ARV_GV_STREAM_OPTION_PACKET_SOCKET_DISABLED",
-			  "packet-socket-disabled" },
-			{ 0, NULL, NULL }
-		};
-		the_type = g_enum_register_static (
-				g_intern_static_string ("ArvGvStreamOption"),
-				values);
-	}
-	return the_type;
-}
-
-GType
-arv_gv_stream_socket_buffer_get_type (void)
-{
-	static GType the_type = 0;
-
-	if (the_type == 0)
-	{
-		static const GEnumValue values[] = {
-			{ ARV_GV_STREAM_SOCKET_BUFFER_FIXED,
-			  "ARV_GV_STREAM_SOCKET_BUFFER_FIXED",
-			  "fixed" },
-			{ ARV_GV_STREAM_SOCKET_BUFFER_AUTO,
-			  "ARV_GV_STREAM_SOCKET_BUFFER_AUTO",
-			  "auto" },
-			{ 0, NULL, NULL }
-		};
-		the_type = g_enum_register_static (
-				g_intern_static_string ("ArvGvStreamSocketBuffer"),
-				values);
-	}
-	return the_type;
-}
-
-GType
-arv_gv_stream_packet_resend_get_type (void)
-{
-	static GType the_type = 0;
-
-	if (the_type == 0)
-	{
-		static const GEnumValue values[] = {
-			{ ARV_GV_STREAM_PACKET_RESEND_NEVER,
-			  "ARV_GV_STREAM_PACKET_RESEND_NEVER",
-			  "never" },
-			{ ARV_GV_STREAM_PACKET_RESEND_ALWAYS,
-			  "ARV_GV_STREAM_PACKET_RESEND_ALWAYS",
-			  "always" },
-			{ 0, NULL, NULL }
-		};
-		the_type = g_enum_register_static (
-				g_intern_static_string ("ArvGvStreamPacketResend"),
-				values);
-	}
-	return the_type;
-}
-
-#include "arvxmlschema.h"
-
-GType
-arv_xml_schema_error_get_type (void)
-{
-	static GType the_type = 0;
-
-	if (the_type == 0)
-	{
-		static const GEnumValue values[] = {
-			{ ARV_XML_SCHEMA_ERROR_INVALID_STRUCTURE,
-			  "ARV_XML_SCHEMA_ERROR_INVALID_STRUCTURE",
-			  "structure" },
-			{ 0, NULL, NULL }
-		};
-		the_type = g_enum_register_static (
-				g_intern_static_string ("ArvXmlSchemaError"),
-				values);
-	}
-	return the_type;
-}
-
 #include "arvgvcp.h"
 
 GType
@@ -944,6 +832,108 @@ arv_gvsp_payload_type_get_type (void)
 	return the_type;
 }
 
+#include "arvgvstream.h"
+
+GType
+arv_gv_stream_option_get_type (void)
+{
+	static GType the_type = 0;
+
+	if (the_type == 0)
+	{
+		static const GEnumValue values[] = {
+			{ ARV_GV_STREAM_OPTION_NONE,
+			  "ARV_GV_STREAM_OPTION_NONE",
+			  "none" },
+			{ ARV_GV_STREAM_OPTION_PACKET_SOCKET_DISABLED,
+			  "ARV_GV_STREAM_OPTION_PACKET_SOCKET_DISABLED",
+			  "packet-socket-disabled" },
+			{ 0, NULL, NULL }
+		};
+		the_type = g_enum_register_static (
+				g_intern_static_string ("ArvGvStreamOption"),
+				values);
+	}
+	return the_type;
+}
+
+GType
+arv_gv_stream_socket_buffer_get_type (void)
+{
+	static GType the_type = 0;
+
+	if (the_type == 0)
+	{
+		static const GEnumValue values[] = {
+			{ ARV_GV_STREAM_SOCKET_BUFFER_FIXED,
+			  "ARV_GV_STREAM_SOCKET_BUFFER_FIXED",
+			  "fixed" },
+			{ ARV_GV_STREAM_SOCKET_BUFFER_AUTO,
+			  "ARV_GV_STREAM_SOCKET_BUFFER_AUTO",
+			  "auto" },
+			{ 0, NULL, NULL }
+		};
+		the_type = g_enum_register_static (
+				g_intern_static_string ("ArvGvStreamSocketBuffer"),
+				values);
+	}
+	return the_type;
+}
+
+GType
+arv_gv_stream_packet_resend_get_type (void)
+{
+	static GType the_type = 0;
+
+	if (the_type == 0)
+	{
+		static const GEnumValue values[] = {
+			{ ARV_GV_STREAM_PACKET_RESEND_NEVER,
+			  "ARV_GV_STREAM_PACKET_RESEND_NEVER",
+			  "never" },
+			{ ARV_GV_STREAM_PACKET_RESEND_ALWAYS,
+			  "ARV_GV_STREAM_PACKET_RESEND_ALWAYS",
+			  "always" },
+			{ 0, NULL, NULL }
+		};
+		the_type = g_enum_register_static (
+				g_intern_static_string ("ArvGvStreamPacketResend"),
+				values);
+	}
+	return the_type;
+}
+
+#include "arvstream.h"
+
+GType
+arv_stream_callback_type_get_type (void)
+{
+	static GType the_type = 0;
+
+	if (the_type == 0)
+	{
+		static const GEnumValue values[] = {
+			{ ARV_STREAM_CALLBACK_TYPE_INIT,
+			  "ARV_STREAM_CALLBACK_TYPE_INIT",
+			  "init" },
+			{ ARV_STREAM_CALLBACK_TYPE_EXIT,
+			  "ARV_STREAM_CALLBACK_TYPE_EXIT",
+			  "exit" },
+			{ ARV_STREAM_CALLBACK_TYPE_START_BUFFER,
+			  "ARV_STREAM_CALLBACK_TYPE_START_BUFFER",
+			  "start-buffer" },
+			{ ARV_STREAM_CALLBACK_TYPE_BUFFER_DONE,
+			  "ARV_STREAM_CALLBACK_TYPE_BUFFER_DONE",
+			  "buffer-done" },
+			{ 0, NULL, NULL }
+		};
+		the_type = g_enum_register_static (
+				g_intern_static_string ("ArvStreamCallbackType"),
+				values);
+	}
+	return the_type;
+}
+
 #include "arvuvcp.h"
 
 GType
@@ -1087,6 +1077,28 @@ arv_uvsp_payload_type_get_type (void)
 	return the_type;
 }
 
+#include "arvxmlschema.h"
+
+GType
+arv_xml_schema_error_get_type (void)
+{
+	static GType the_type = 0;
+
+	if (the_type == 0)
+	{
+		static const GEnumValue values[] = {
+			{ ARV_XML_SCHEMA_ERROR_INVALID_STRUCTURE,
+			  "ARV_XML_SCHEMA_ERROR_INVALID_STRUCTURE",
+			  "structure" },
+			{ 0, NULL, NULL }
+		};
+		the_type = g_enum_register_static (
+				g_intern_static_string ("ArvXmlSchemaError"),
+				values);
+	}
+	return the_type;
+}
+
 
 /* Generated data ends here */
 
