@@ -122,6 +122,22 @@ static GRegex *arv_gv_device_url_regex = NULL;
 	return arv_gv_device_url_regex;
 }
 
+static void
+_flush_socket_buffer(ArvGvDeviceIOData *io_data)
+{
+	GError *local_error = NULL;
+	gboolean success = TRUE;
+
+	while (success &&
+		g_poll (&io_data->poll_in_event, 1, 0) > 0
+	)
+	{
+		arv_debug_device ("[GvDevice::flush_receive_socket] Flush packet");
+		success = g_socket_receive (io_data->socket, io_data->buffer,
+						  ARV_GV_DEVICE_BUFFER_SIZE, NULL, &local_error) > 0;
+	}
+}
+
 static gboolean
 _read_memory (ArvGvDeviceIOData *io_data, guint64 address, guint32 size, void *buffer, GError **error)
 {
@@ -157,6 +173,7 @@ _read_memory (ArvGvDeviceIOData *io_data, guint64 address, guint32 size, void *b
 
 		arv_gvcp_packet_debug (packet, ARV_DEBUG_LEVEL_LOG);
 
+		_flush_socket_buffer(io_data);
 		success = g_socket_send_to (io_data->socket, io_data->device_address,
 					    (const char *) packet, packet_size,
 					    NULL, &local_error) >= 0;
@@ -276,6 +293,7 @@ _write_memory (ArvGvDeviceIOData *io_data, guint64 address, guint32 size, void *
 
 		arv_gvcp_packet_debug (packet, ARV_DEBUG_LEVEL_LOG);
 
+		_flush_socket_buffer(io_data);
 		success = g_socket_send_to (io_data->socket, io_data->device_address,
 					    (const char *) packet, packet_size,
 					    NULL, &local_error) >= 0;
@@ -388,6 +406,7 @@ _read_register (ArvGvDeviceIOData *io_data, guint32 address, guint32 *value_plac
 
 		arv_gvcp_packet_debug (packet, ARV_DEBUG_LEVEL_LOG);
 
+		_flush_socket_buffer(io_data);
 		success = g_socket_send_to (io_data->socket, io_data->device_address,
 					    (const char *) packet, packet_size,
 					    NULL, &local_error) >= 0;
@@ -505,6 +524,7 @@ _write_register (ArvGvDeviceIOData *io_data, guint32 address, guint32 value, GEr
 
 		arv_gvcp_packet_debug (packet, ARV_DEBUG_LEVEL_LOG);
 
+		_flush_socket_buffer(io_data);
 		success = g_socket_send_to (io_data->socket, io_data->device_address, (const char *) packet, packet_size,
 					    NULL, &local_error) >= 0;
 
@@ -714,7 +734,7 @@ arv_gv_device_get_packet_size (ArvGvDevice *gv_device)
 }
 
 void
-arv_gv_device_set_packet_size (ArvGvDevice *gv_device, guint packet_size)
+arv_gv_device_set_packet_size (ArvGvDevice *gv_device, gint packet_size)
 {
 	g_return_if_fail (packet_size > 0);
 
@@ -770,7 +790,7 @@ arv_gv_device_auto_packet_size (ArvGvDevice *gv_device)
 	interface_address = g_inet_socket_address_get_address (G_INET_SOCKET_ADDRESS (io_data->interface_address));
 	interface_socket_address = g_inet_socket_address_new (interface_address, 0);
 	socket = g_socket_new (G_SOCKET_FAMILY_IPV4, G_SOCKET_TYPE_DATAGRAM, G_SOCKET_PROTOCOL_UDP, NULL);
-	g_socket_bind (socket, interface_socket_address, TRUE, NULL);
+	g_socket_bind (socket, interface_socket_address, FALSE, NULL);
 	local_address = G_INET_SOCKET_ADDRESS (g_socket_get_local_address (socket, NULL));
 	port = g_inet_socket_address_get_port (local_address);
 
@@ -780,7 +800,6 @@ arv_gv_device_auto_packet_size (ArvGvDevice *gv_device)
 
 	g_clear_object (&local_address);
 	g_clear_object (&interface_socket_address);
-	g_clear_object (&interface_address);
 
 	do_not_fragment = arv_device_get_boolean_feature_value (device, "GevSCPSDoNotFragment");
 	arv_device_set_boolean_feature_value (device, "GevSCPSDoNotFragment", TRUE);
@@ -1350,7 +1369,7 @@ arv_gv_device_new (GInetAddress *interface_address, GInetAddress *device_address
 	io_data->socket = g_socket_new (G_SOCKET_FAMILY_IPV4,
 					G_SOCKET_TYPE_DATAGRAM,
 					G_SOCKET_PROTOCOL_UDP, NULL);
-	g_socket_bind (io_data->socket, io_data->interface_address, TRUE, NULL);
+	g_socket_bind (io_data->socket, io_data->interface_address, FALSE, NULL);
 
 	io_data->buffer = g_malloc (ARV_GV_DEVICE_BUFFER_SIZE);
 	io_data->gvcp_n_retries = ARV_GV_DEVICE_GVCP_N_RETRIES_DEFAULT;
