@@ -602,30 +602,37 @@ ArvGstCapsInfos arv_gst_caps_infos[] = {
 	{
 		ARV_PIXEL_FORMAT_MONO_8,
 		"video/x-raw, format=(string)GRAY8",
-		"video/x-raw", "GRAY8",
+		"video/x-raw", 		"GRAY8",
 		"video/x-raw-gray, bpp=(int)8, depth=(int)8",
 		"video/x-raw-gray",	8,	8,	0
 	},
 	{
-		ARV_PIXEL_FORMAT_MONO_10,
+		ARV_PIXEL_FORMAT_MONO_16,
 		"video/x-raw, format=(string)GRAY16_LE",
-		"video/x-raw", 	"GRAY16_LE",
-		"video/x-raw-gray, bpp=(int)16, depth=(int)10",
-		"video/x-raw-gray",	16,	10,	0
+		"video/x-raw",		"GRAY16_LE",
+		"video/x-raw-gray, bpp=(int)16, depth=(int)16",
+		"video/x-raw-gray",	16,	16,	0
 	},
 	{
 		ARV_PIXEL_FORMAT_MONO_12,
 		"video/x-raw, format=(string)GRAY16_LE",
-		"video/x-raw",	"GRAY16_LE",
+		"video/x-raw",		"GRAY16_LE",
 		"video/x-raw-gray, bpp=(int)16, depth=(int)12",
 		"video/x-raw-gray",	16,	12,	0
 	},
 	{
-		ARV_PIXEL_FORMAT_MONO_16,
+		ARV_PIXEL_FORMAT_MONO_12_PACKED,
 		"video/x-raw, format=(string)GRAY16_LE",
-		"video/x-raw",	"GRAY16_LE",
-		"video/x-raw-gray, bpp=(int)16, depth=(int)16",
-		"video/x-raw-gray",	16,	16,	0
+		"video/x-raw",		"GRAY16_LE",
+		"video/x-raw-gray, bpp=(int)12, depth=(int)12",
+		"video/x-raw-gray",	12,	12,	0
+	},
+	{
+		ARV_PIXEL_FORMAT_MONO_10,
+		"video/x-raw, format=(string)GRAY16_LE",
+		"video/x-raw", 		"GRAY16_LE",
+		"video/x-raw-gray, bpp=(int)16, depth=(int)10",
+		"video/x-raw-gray",	16,	10,	0
 	},
 	{
 		ARV_PIXEL_FORMAT_BAYER_GR_8,
@@ -662,27 +669,28 @@ ArvGstCapsInfos arv_gst_caps_infos[] = {
 	{
 		ARV_PIXEL_FORMAT_YUV_422_PACKED,
 		"video/x-raw, format=(string)UYVY",
-		"video/x-raw",	"UYVY",
+		"video/x-raw",		"UYVY",
 		"video/x-raw-yuv, format=(fourcc)UYVY",
 		"video/x-raw-yuv",	0,	0,	ARV_MAKE_FOURCC ('U','Y','V','Y')
 	},
 	{
 		ARV_PIXEL_FORMAT_YUV_422_YUYV_PACKED,
 		"video/x-raw, format=(string)YUY2",
+		"video/x-raw", 		"YUY2",
 		"video/x-raw-yuv, format=(fourcc)YUYU2",
 		"video/x-raw-yuv",	0,	0,	ARV_MAKE_FOURCC ('Y','U','Y','2')
 	},
 	{
 		ARV_PIXEL_FORMAT_RGB_8_PACKED,
 		"video/x-raw, format=(string)RGB",
-		"video/x-raw",	"RGB",
+		"video/x-raw",		"RGB",
 		"video/x-raw-rgb, format=(string)RGB, bpp=(int)24, depth=(int)24",
 		"video/x-raw-rgb",	24,	24,	0
 	},
 	{
 		ARV_PIXEL_FORMAT_CUSTOM_YUV_422_YUYV_PACKED,
 		"video/x-raw, format=(string)YUY2",
-		"video/x-raw",	"YUY2",
+		"video/x-raw",		"YUY2",
 		"video/x-raw-yuv, format=(fourcc)YUYU2",
 		"video/x-raw-yuv",	0,	0,	ARV_MAKE_FOURCC ('Y','U','Y','2')
 	}
@@ -715,14 +723,16 @@ arv_pixel_format_to_gst_caps_string (ArvPixelFormat pixel_format)
 }
 
 ArvPixelFormat
-arv_pixel_format_from_gst_caps (const char *name, const char *format)
+arv_pixel_format_from_gst_caps (const char *name, const char *format, int bpp, int depth)
 {
 	unsigned int i;
 
 	g_return_val_if_fail (name != NULL, 0);
 
 	for (i = 0; i < G_N_ELEMENTS (arv_gst_caps_infos); i++) {
-		if (strcmp (name, arv_gst_caps_infos[i].name) != 0)
+		if (strcmp (name, arv_gst_caps_infos[i].name) != 0 ||
+		    (depth > 0 && depth != arv_gst_caps_infos[i].depth) ||
+		    (bpp > 0 && bpp != arv_gst_caps_infos[i].bpp))
 			continue;
 
 		if (strcmp (name, "video/x-raw") == 0 &&
@@ -769,11 +779,11 @@ arv_pixel_format_from_gst_0_10_caps (const char *name, int bpp, int depth, guint
 			continue;
 
 		if (strcmp (name, "video/x-raw-yuv") == 0 &&
-		    fourcc == arv_gst_caps_infos[i].fourcc)
+		    (fourcc <= 0 || fourcc == arv_gst_caps_infos[i].fourcc))
 			return arv_gst_caps_infos[i].pixel_format;
 
-		if (depth == arv_gst_caps_infos[i].depth &&
-		    bpp == arv_gst_caps_infos[i].bpp &&
+		if ((depth <= 0 || depth == arv_gst_caps_infos[i].depth) &&
+		    (bpp <= 0 || bpp == arv_gst_caps_infos[i].bpp) &&
 		    fourcc == arv_gst_caps_infos[i].fourcc)
 			return arv_gst_caps_infos[i].pixel_format;
 	}
