@@ -6,91 +6,97 @@ typedef struct {
 	const char *test_name;
 	const char *expression;
 	gint64 result_int64;
+	gboolean expected_error_int64;
 	double result_double;
 } ExpressionTestData;
 
 static const ExpressionTestData expression_test_data[] = {
-	{"/evaluator/addition", 			"10+2", 		12, 	12.0},
-	{"/evaluator/parentheses",			"(24+2)*2",		52, 	52.0},
-	{"/evaluator/precedence",			"24+2*8",		40, 	40.0},
-	{"/evaluator/ternary-true",			"1=1?1:0",		1,	1.0},
-	{"/evaluator/ternary-false",			"1=0?1:0",		0,	0.0},
-	{"/evaluator/greater-true",			"2>1",			1,	1.0},
-	{"/evaluator/greater-false",			"2>2",			0,	0.0},
-	{"/evaluator/lower-true",			"1<2",			1,	1.0},
-	{"/evaluator/lower-false",			"2<2",			0,	0.0},
-	{"/evaluator/substraction",			"10-8",			2,	2.0},
-	{"/evaluator/substraction-float",		"10.1-8.1",		2,	2.0},
-	{"/evaluator/multiplication",			"2.5*4",	       	10,	10.0},
-	{"/evaluator/division",				"10/4",			2,	2.5},
-	{"/evaluator/division-float",			"10.0/4",		2,	2.5},
-	{"/evaluator/minus",				"4*-3",			-12,	-12.0},
-	{"/evaluator/plus",				"4*+3",			12,	12.0},
-	{"/evaluator/remainder",			"10%3",			1,	1.0},
-	{"/evaluator/power",				"2**10",		1024,	1024.0},
-	{"/evaluator/power-precedence",			"2**10*2",		2048,	2048.0},
-	{"/evaluator/ln",				"LN(E)",		1,	1.0},
-	{"/evaluator/lg",				"LG(10)",		1,	1.0},
-	{"/evaluator/sqrt",				"SQRT(16)",		4,	4.0},
-	{"/evaluator/tan",				"TAN(0)",		0,	0.0},
-	{"/evaluator/atan",				"ATAN(0)",		0,	0.0},
-	{"/evaluator/exp",				"EXP(1)",		2,	M_E},
-	{"/evaluator/trunc-plus",			"TRUNC(10.7)",		10,	10.0},
-	{"/evaluator/trunc-minus",			"TRUNC(-11.9)",		-11,	-11.0},
-	{"/evaluator/floor-plus",			"FLOOR(10.7)",		10,	10.0},
-	{"/evaluator/floor-minus",			"FLOOR(-11.9)",		-12,	-12.0},
-	{"/evaluator/ceil-plus",			"CEIL(10.7)",		11,	11.0},
-	{"/evaluator/ceil-minus",			"CEIL(-11.9)",		-11,	-11.0},
-	{"/evaluator/sign-plus",			"SGN(2)",		1,	1.0},
-	{"/evaluator/sign-minus",			"SGN(-2)",		-1,	-1.0},
-	{"/evaluator/sign-zero",			"SGN(0)",		0,	0.0},
-	{"/evaluator/sign-plus-float",			"SGN(2.0)",		1,	1.0},
-	{"/evaluator/sign-minus-floa",			"SGN(-2.0)",		-1,	-1.0},
-	{"/evaluator/sign-zero-float",			"SGN(0.0)",		0,	0.0},
-	{"/evaluator/neg",				"NEG(-1)",		1,	1.0},
-	{"/evaluator/neg-float",			"NEG(-2.5)",		2,	2.5},
-	{"/evaluator/and",				"255 & 8",		8,	8.0},
-	{"/evaluator/or",				"128 | 8",		136,	136.0},
-	{"/evaluator/xor",				"3 ^ 1",		2,	2.0},
-	{"/evaluator/not",				"~255",			-256,   -256.0},
-	{"/evaluator/not-equal-true",			"1<>2",			1,	1.0},
-	{"/evaluator/not-equal-false",			"1<>1",			0,	0.0},
-	{"/evaluator/equal-true",			"1=1",			1,	1.0},
-	{"/evaluator/equal-false",			"1=2",			0,	0.0},
-	{"/evaluator/less-true",			"1<2",			1,	1.0},
-	{"/evaluator/less-false",			"1<1",			0,	0.0},
-	{"/evaluator/greater-or-equal-true",		"2>=2",			1,	1.0},
-	{"/evaluator/greater-or-equal-false",		"1>=2",			0,	0.0},
-	{"/evaluator/less-or-equal-true",		"2<=2",			1,	1.0},
-	{"/evaluator/less-or-equal-false",		"2<=1",			0,	0.0},
-	{"/evaluator/not-equal-true-double",		"2.1<>2",		1,	1.0},
-	{"/evaluator/not-equal-false-double",		"1.0<>1",		0,	0.0},
-	{"/evaluator/equal-true-double",		"1.0=1",		1,	1.0},
-	{"/evaluator/equal-false-double",		"2.1=2",		0,	0.0},
-	{"/evaluator/greater-true-double",		"2.1>2",		1,	1.0},
-	{"/evaluator/greater-false-double",		"2>2.1",		0,	0.0},
-	{"/evaluator/less-true-double",			"2<2.1",		1,	1.0},
-	{"/evaluator/less-false-double",		"2.1<2",		0,	0.0},
-	{"/evaluator/greater-or-equal-true-double",	"2.1>=2",		1,	1.0},
-	{"/evaluator/greater-or-equal-false-double",	"2>=2.1",		0,	0.0},
-	{"/evaluator/less-or-equal-true-double",	"2<=2.1",		1,	1.0},
-	{"/evaluator/less-or-equal-false-double",	"2.1<=2",		0,	0.0},
-	{"/evaluator/logical-and-true",			"(2=2)&&(1=1)",		1,	1.0},
-	{"/evaluator/logical-and-false",		"(2=2)&&(1=2)",		0,	0.0},
-	{"/evaluator/logical-or-true",			"(2=2)||(1=2)",		1,	1.0},
-	{"/evaluator/logical-or-false",			"(1=2)||(0=2)",		0,	0.0},
-	{"/evaluator/left-shift",			"1<<4",			16,	16.0},
-	{"/evaluator/right-shift",			"16>>4",		1,	1.0},
-	{"/evaluator/cos",				"COS(PI)",		-1,	-1.0},
-	{"/evaluator/sin",				"SIN(-PI/2)",		-1,	-1.0},
-	{"/evaluator/acos",				"ACOS(1)",		0,	0.0},
-	{"/evaluator/asin",				"ASIN(0)",		0,	0.0},
-	{"/evaluator/abs",				"ABS(-1)",		1,	1.0},
-	{"/evaluator/abs-float",			"ABS(-10.3)",		10,	10.3},
-	{"/evaluator/abs64bits",			"ABS(-10000000000)",		10000000000,	1e10},
+	{"/evaluator/addition", 			"10+2", 			12, 	FALSE,	12.0},
+	{"/evaluator/parentheses",			"(24+2)*2",			52, 	FALSE,	52.0},
+	{"/evaluator/precedence",			"24+2*8",			40, 	FALSE,	40.0},
+	{"/evaluator/ternary-true",			"1=1?1:0",			1,	FALSE,	1.0},
+	{"/evaluator/ternary-false",			"1=0?1:0",			0,	FALSE,	0.0},
+	{"/evaluator/greater-true",			"2>1",				1,	FALSE,	1.0},
+	{"/evaluator/greater-false",			"2>2",				0,	FALSE,	0.0},
+	{"/evaluator/lower-true",			"1<2",				1,	FALSE,	1.0},
+	{"/evaluator/lower-false",			"2<2",				0,	FALSE,	0.0},
+	{"/evaluator/substraction",			"10-8",				2,	FALSE,	2.0},
+	{"/evaluator/substraction-float",		"10.1-8.1",			2,	FALSE,	2.0},
+	{"/evaluator/multiplication",			"2.5*4",	       		8,	FALSE,	10.0},
+	{"/evaluator/division",				"10/4",				2,	FALSE,	2.5},
+	{"/evaluator/division-float",			"10.0/4",			2,	FALSE,	2.5},
+	{"/evaluator/minus",				"4*-3",				-12,	FALSE,	-12.0},
+	{"/evaluator/plus",				"4*+3",				12,	FALSE,	12.0},
+	{"/evaluator/remainder",			"10%3",				1,	FALSE,	1.0},
+	{"/evaluator/power",				"2**10",			1024,	FALSE,	1024.0},
+	{"/evaluator/power-precedence",			"2**10*2",			2048,	FALSE,	2048.0},
+	{"/evaluator/ln",				"LN(E)",			1,	TRUE,	1.0},
+	{"/evaluator/lg",				"LG(10)",			1,	TRUE,	1.0},
+	{"/evaluator/sqrt",				"SQRT(16)",			4,	TRUE,	4.0},
+	{"/evaluator/tan",				"TAN(0)",			0,	TRUE,	0.0},
+	{"/evaluator/atan",				"ATAN(0)",			0,	TRUE,	0.0},
+	{"/evaluator/exp",				"EXP(1)",			2,	TRUE,	M_E},
+	{"/evaluator/trunc-plus",			"TRUNC(10.7)",			10,	TRUE,	10.0},
+	{"/evaluator/trunc-minus",			"TRUNC(-11.9)",			-11,	TRUE,	-11.0},
+	{"/evaluator/round-plus",			"ROUND(10.1)",			10,	TRUE,	10.0},
+	{"/evaluator/round-plus-plus",			"ROUND(10.9)",			11,	TRUE,	11.0},
+	{"/evaluator/round-minus",			"ROUND(-20.1)",			-20,	TRUE,	-20.0},
+	{"/evaluator/round-minus-minus",		"ROUND(-20.9)",			-21,	TRUE,	-21.0},
+	{"/evaluator/floor-plus",			"FLOOR(10.7)",			10,	TRUE,	10.0},
+	{"/evaluator/floor-minus",			"FLOOR(-11.9)",			-12,	TRUE,	-12.0},
+	{"/evaluator/ceil-plus",			"CEIL(10.7)",			11,	TRUE,	11.0},
+	{"/evaluator/ceil-minus",			"CEIL(-11.9)",			-11,	TRUE,	-11.0},
+	{"/evaluator/sign-plus",			"SGN(2)",			1,	FALSE,	1.0},
+	{"/evaluator/sign-minus",			"SGN(-2)",			-1,	FALSE,	-1.0},
+	{"/evaluator/sign-zero",			"SGN(0)",			0,	FALSE,	0.0},
+	{"/evaluator/sign-plus-float",			"SGN(2.0)",			1,	FALSE,	1.0},
+	{"/evaluator/sign-minus-floa",			"SGN(-2.0)",			-1,	FALSE,	-1.0},
+	{"/evaluator/sign-zero-float",			"SGN(0.0)",			0,	FALSE,	0.0},
+	{"/evaluator/neg",				"NEG(-1)",			1,	FALSE,	1.0},
+	{"/evaluator/neg-float",			"NEG(-2.5)",			2,	FALSE,	2.5},
+	{"/evaluator/and",				"255 & 8",			8,	FALSE,	8.0},
+	{"/evaluator/or",				"128 | 8",			136,	FALSE,	136.0},
+	{"/evaluator/xor",				"3 ^ 1",			2,	FALSE,	2.0},
+	{"/evaluator/not",				"~255",				-256,   FALSE,	-256.0},
+	{"/evaluator/not-equal-true",			"1<>2",				1,	FALSE,	1.0},
+	{"/evaluator/not-equal-false",			"1<>1",				0,	FALSE,	0.0},
+	{"/evaluator/equal-true",			"1=1",				1,	FALSE,	1.0},
+	{"/evaluator/equal-false",			"1=2",				0,	FALSE,	0.0},
+	{"/evaluator/less-true",			"1<2",				1,	FALSE,	1.0},
+	{"/evaluator/less-false",			"1<1",				0,	FALSE,	0.0},
+	{"/evaluator/greater-or-equal-true",		"2>=2",				1,	FALSE,	1.0},
+	{"/evaluator/greater-or-equal-false",		"1>=2",				0,	FALSE,	0.0},
+	{"/evaluator/less-or-equal-true",		"2<=2",				1,	FALSE,	1.0},
+	{"/evaluator/less-or-equal-false",		"2<=1",				0,	FALSE,	0.0},
+	{"/evaluator/not-equal-true-double",		"2.1<>2",			0,	FALSE,	1.0},
+	{"/evaluator/not-equal-false-double",		"1.0<>1",			0,	FALSE,	0.0},
+	{"/evaluator/equal-true-double",		"1.0=1",			1,	FALSE,	1.0},
+	{"/evaluator/equal-false-double",		"2.1=2",			1,	FALSE,	0.0},
+	{"/evaluator/greater-true-double",		"2.1>2",			0,	FALSE,	1.0},
+	{"/evaluator/greater-false-double",		"2>2.1",			0,	FALSE,	0.0},
+	{"/evaluator/less-true-double",			"2<2.1",			0,	FALSE,	1.0},
+	{"/evaluator/less-false-double",		"2.1<2",			0,	FALSE,	0.0},
+	{"/evaluator/greater-or-equal-true-double",	"2.1>=2",			1,	FALSE,	1.0},
+	{"/evaluator/greater-or-equal-false-double",	"2>=2.1",			1,	FALSE,	0.0},
+	{"/evaluator/less-or-equal-true-double",	"2<=2.1",			1,	FALSE,	1.0},
+	{"/evaluator/less-or-equal-false-double",	"2.1<=2",			1,	FALSE,	0.0},
+	{"/evaluator/logical-and-true",			"(2=2)&&(1=1)",			1,	FALSE,	1.0},
+	{"/evaluator/logical-and-false",		"(2=2)&&(1=2)",			0,	FALSE,	0.0},
+	{"/evaluator/logical-or-true",			"(2=2)||(1=2)",			1,	FALSE,	1.0},
+	{"/evaluator/logical-or-false",			"(1=2)||(0=2)",			0,	FALSE,	0.0},
+	{"/evaluator/left-shift",			"1<<4",				16,	FALSE,	16.0},
+	{"/evaluator/right-shift",			"16>>4",			1,	FALSE,	1.0},
+	{"/evaluator/cos",				"COS(PI)",			-1,	TRUE,	-1.0},
+	{"/evaluator/sin",				"SIN(-PI/2)",			-1,	TRUE,	-1.0},
+	{"/evaluator/acos",				"ACOS(1)",			0,	TRUE,	0.0},
+	{"/evaluator/asin",				"ASIN(0)",			0,	TRUE,	0.0},
+	{"/evaluator/abs",				"ABS(-1)",			1,	TRUE,	1.0},
+	{"/evaluator/abs-float",			"ABS(-10.3)",			10,	TRUE,	10.3},
+	{"/evaluator/abs64bits",			"ABS(-10000000000)",		10000000000,	TRUE,	1e10},
 
-	{"/evaluator/bugs/681048-remaining-op",		"(0 & 1)=0?((0 & 1)+2):1",	2,	2.0},
-	{"/evaluator/bugs/743025-division-by-zero",	"(4/(20/10000))",		2000,	2000.0}
+	{"/evaluator/bugs/681048-remaining-op",		"(0 & 1)=0?((0 & 1)+2):1",		2,	FALSE,	2.0},
+	{"/evaluator/bugs/743025-division-by-zero",	"(4/(20/10000))",			2000,	TRUE,	2000.0},
+	{"/evaluator/bugs/gh98-not-operatorprecedence",	"(~(~0xC2000221|0xFEFFFFFF)) ? 2:0", 	0, 	FALSE,	0.0}
 };
 
 static void
@@ -105,12 +111,16 @@ expression_test (ExpressionTestData *data)
 	evaluator = arv_evaluator_new (data->expression);
 
 	v_int64 = arv_evaluator_evaluate_as_int64 (evaluator, &error);
-	g_assert (error == NULL);
+	if (data->expected_error_int64) {
+		g_assert (error != NULL);
+		g_clear_error (&error);
+	} else {
+		g_assert (error == NULL);
+		g_assert_cmpint (v_int64, ==, data->result_int64);
+	}
 
 	v_double = arv_evaluator_evaluate_as_double (evaluator, &error);
 	g_assert (error == NULL);
-
-	g_assert_cmpint (v_int64, ==, data->result_int64);
 	g_assert_cmpfloat (v_double, ==, data->result_double);
 
 	expression = arv_evaluator_get_expression (evaluator);
